#!/bin/bash
# ==============================================================================
# SCRIPTS FOR CHROOTING STUNNEL 4.x ON DEBIAN SARGE/ETCH, version 0.2
# Project home page: http://tsampa.org/computing/servers/debian/stunnel/
# (c) Kristoffer Lindqvist <kris@tsampa.org>, 2005-2007
# ------------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version. See LICENSE for details.
# ==============================================================================
#
# This is finalizejail.sh. See README for usage details.

if [ ! $# == 2 ]; then
  echo "Usage: $0 chdir user" 
  exit 
fi 
     
CHDIR=$1
USER=$2

# make /tmp directory with proper permissions
mkdir ${CHDIR}/tmp && chmod 1777 ${CHDIR}/tmp &&
echo '...created /tmp'

# make /dev/null
mkdir ${CHDIR}/dev &&
mknod ${CHDIR}/dev/null c 1 3 &&
chown root:root ${CHDIR}/dev/null &&
chmod 666 ${CHDIR}/dev/null &&
echo '...created /dev/null'

# SSL needs /dev/urandom to work
mknod -m 644 ${CHDIR}/dev/urandom c 1 9 &&
echo '...created /dev/urandom'

# make sure stunnel can write its pid file
mkdir -p ${CHDIR}/var/run/stunnel4
chown ${USER}:${USER} ${CHDIR}/var/run/stunnel4 &&
chmod g+w ${CHDIR}/var/run/stunnel4 &&
echo '...chowned and chmodded /var/run/stunnel4'

# make a directory for the certificate
mkdir ${CHDIR}/etc/ssl &&
echo '...created /etc/ssl directory for certificates'

# generate a certificate, feel free to replace if you want
openssl req -new -x509 -days 1095 -nodes -config /usr/share/doc/stunnel4/examples/stunnel.cnf -out ${CHDIR}/etc/ssl/stunnel.pem -keyout ${CHDIR}/etc/ssl/stunnel.pem &&
chown ${USER}:${USER} ${CHDIR}/etc/ssl/stunnel.pem &&
chmod 600 ${CHDIR}/etc/ssl/stunnel.pem &&
echo '...successfully generated a default certificate in /etc/ssl'

# copy over stunnel.conf skeleton
cp templates/stunnel.conf ${CHDIR}/etc/stunnel &&
echo '...copied stunnel.conf skeleton into /etc/stunnel'

echo 'DONE! Now tweak stunnel.conf to your liking, then all systems go!'
